@@ -10,7 +10,7 @@ import re
 import json
 import time
 from .base import Base
-from ..utils.misc import *
+from ..utils import filterBadCharacter
 
 
 '''AcFun视频下载器类'''
@@ -29,7 +29,7 @@ class AcFun(Base):
             'source': self.source,
             'download_url': download_url,
             'savedir': self.config['savedir'],
-            'savename': '_'.join([self.source, filterBadCharacter(title)]),
+            'savename': filterBadCharacter(title),
             'ext': 'm3u8',
         }
         return [videoinfo]
